@@ -4,6 +4,14 @@
 //!
 //! Hello world!
 
+// Globals are declared outside all other scopes.
+static LANGUAGE: &str = "Rust";
+const THRESHOLD: i32 = 10;
+
+pub fn array_length(array: &[u8]) -> usize {
+    array.len()
+}
+
 pub enum Devices {
     Pixelbook,
     Pixel5,
